.. Pyrepo documentation master file, created by
   sphinx-quickstart on Sun May 18 23:24:58 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

User Guide
==========

Contents:

.. toctree::
   :maxdepth: 2

   intro
   install
   quickstart

API
===

.. toctree::
    :maxdepth: 2

    api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

